﻿################################################################################
## Initialization
################################################################################

init offset = -1


################################################################################
## Styles
################################################################################

style default:
    properties gui.text_properties()
    language gui.language

style input:
    properties gui.text_properties("input", accent=True)
    adjust_spacing False

style hyperlink_text:
    properties gui.text_properties("hyperlink", accent=True)
    hover_underline True

style gui_text:
    properties gui.text_properties("interface")


style button:
    properties gui.button_properties("button")

style button_text is gui_text:
    properties gui.text_properties("button")
    yalign 0.5


style label_text is gui_text:
    properties gui.text_properties("label", accent=True)

style prompt_text is gui_text:
    properties gui.text_properties("prompt")


style bar:
    ysize gui.bar_size
    left_bar Frame("gui/bar/left.png", gui.bar_borders, tile=gui.bar_tile)
    right_bar Frame("gui/bar/right.png", gui.bar_borders, tile=gui.bar_tile)

style vbar:
    xsize gui.bar_size
    top_bar Frame("gui/bar/top.png", gui.vbar_borders, tile=gui.bar_tile)
    bottom_bar Frame("gui/bar/bottom.png", gui.vbar_borders, tile=gui.bar_tile)

style scrollbar:
    ysize gui.scrollbar_size
    base_bar Frame("gui/scrollbar/horizontal_[prefix_]bar.png", gui.scrollbar_borders, tile=gui.scrollbar_tile)
    thumb Frame("gui/scrollbar/horizontal_[prefix_]thumb.png", gui.scrollbar_borders, tile=gui.scrollbar_tile)

style vscrollbar:
    xsize gui.scrollbar_size
    base_bar Frame("gui/scrollbar/vertical_[prefix_]bar.png", gui.vscrollbar_borders, tile=gui.scrollbar_tile)
    thumb Frame("gui/scrollbar/vertical_[prefix_]thumb.png", gui.vscrollbar_borders, tile=gui.scrollbar_tile)

style slider:
    ysize gui.slider_size
    base_bar Frame("gui/slider/horizontal_[prefix_]bar.png", gui.slider_borders, tile=gui.slider_tile)
    thumb "gui/slider/horizontal_[prefix_]thumb.png"

style vslider:
    xsize gui.slider_size
    base_bar Frame("gui/slider/vertical_[prefix_]bar.png", gui.vslider_borders, tile=gui.slider_tile)
    thumb "gui/slider/vertical_[prefix_]thumb.png"


style frame:
    padding gui.frame_borders.padding
    background Frame("gui/frame.png", gui.frame_borders, tile=gui.frame_tile)



################################################################################
## In-game screens
################################################################################


## Say screen ##################################################################
##
## The say screen is used to display dialogue to the player. It takes two
## parameters, who and what, which are the name of the speaking character and
## the text to be displayed, respectively. (The who parameter can be None if no
## name is given.)
##
## This screen must create a text displayable with id "what", as Ren'Py uses
## this to manage text display. It can also create displayables with id "who"
## and id "window" to apply style properties.
##
## https://www.renpy.org/doc/html/screen_special.html#say

screen say(who, what):

    zorder 100
    style_prefix "say"

    window:
        id "window"

        if who is not None:

            window:
                id "namebox"
                style "namebox"
                text who id "who"

        text what id "what"


    ## If there's a side image, display it above the text. Do not display on the
    ## phone variant - there's no room.
    if not renpy.variant("small"):
        add SideImage() xalign 0.0 yalign 1.0


## Make the namebox available for styling through the Character object.
init python:
    config.character_id_prefixes.append('namebox')

style window is default
style say_label is default
style say_dialogue is default
style say_thought is say_dialogue

style namebox is default
style namebox_label is say_label


style window:
    xalign 0.5
    xfill True
    yalign gui.textbox_yalign
    ysize gui.textbox_height

    background Image("gui/textbox.png", xalign=0.5, yalign=1.0)

style window_cutscene:
    xalign 0.5
    xfill True
    yalign gui.textbox_yalign
    ysize gui.textbox_height

    background Image("gui/textbox.png", xalign=0.5, yalign=1.0)


style namebox:
    xpos gui.name_xpos
    xanchor gui.name_xalign
    xsize gui.namebox_width
    ypos gui.name_ypos
    ysize gui.namebox_height

    background Frame("gui/namebox.png", gui.namebox_borders, tile=gui.namebox_tile, xalign=gui.name_xalign)
    padding gui.namebox_borders.padding

style say_label:
    properties gui.text_properties("name", accent=True)
    xalign gui.name_xalign
    yalign 0.5

style say_dialogue:
    properties gui.text_properties("dialogue")

    xpos gui.dialogue_xpos
    xsize gui.dialogue_width
    ypos gui.dialogue_ypos

style say_label_cutscene:
    properties gui.text_properties("name", accent=True)
    xalign gui.name_xalign
    yalign 0.5

style say_dialogue_cutscene:
    properties gui.text_properties("dialogue")

    xpos gui.dialogue_xpos
    xsize gui.dialogue_width
    ypos gui.dialogue_ypos

## Input screen ################################################################
##
## This screen is used to display renpy.input. The prompt parameter is used to
## pass a text prompt in.
##
## This screen must create an input displayable with id "input" to accept the
## various input parameters.
##
## https://www.renpy.org/doc/html/screen_special.html#input

screen input(prompt):
    style_prefix "input"

    window:

        vbox:
            xalign gui.dialogue_text_xalign
            xpos gui.dialogue_xpos
            xsize gui.dialogue_width
            ypos gui.dialogue_ypos

            text prompt style "input_prompt"
            input id "input"

style input_prompt is default

style input_prompt:
    xalign gui.dialogue_text_xalign
    properties gui.text_properties("input_prompt")

style input:
    xalign gui.dialogue_text_xalign
    xmaximum gui.dialogue_width


## Choice screen ###############################################################
##
## This screen is used to display the in-game choices presented by the menu
## statement. The one parameter, items, is a list of objects, each with caption
## and action fields.
##
## https://www.renpy.org/doc/html/screen_special.html#choice

screen choice(items):
    style_prefix "choice"

    zorder 21

    vbox:
        for i in items:
            textbutton i.caption action i.action #hovered Play("sound", "audio/gui/menu_scroll.ogg")


## When this is true, menu captions will be spoken by the narrator. When false,
## menu captions will be displayed as empty buttons.
define config.narrator_menu = True


style choice_vbox is vbox
style choice_button is button:
    properties gui.button_properties("choice_button")
    activate_sound "audio/gui/confirm.ogg"
style choice_button_text is button_text

style choice_vbox:
    xalign 0.5
    ypos 200
    yanchor 0.3

    spacing gui.choice_spacing

style choice_button is default:
    properties gui.button_properties("choice_button")

style choice_button_text is default:
    properties gui.button_text_properties("choice_button")


## Quick Menu screen ###########################################################
##
## The quick menu is displayed in-game to provide easy access to the out-of-game
## menus.

screen quick_menu():

    ## Ensure this appears on top of other screens.
    zorder 100

    if quick_menu:

        hbox:
            style_prefix "quick"

            xalign 0.5
            yalign 1.0

            #textbutton _("Back") action Rollback()
            if cutscene:
                textbutton _("Back") action Rollback()
                #textbutton _("Skip") action Skip() alternate Skip(fast=True, confirm=True)
                #textbutton _("Auto") action Preference("auto-forward", "toggle")
            textbutton _("History") action ShowMenu('history')
            textbutton _("Save") action ShowMenu('save')
            textbutton _("Load") action ShowMenu('load')
            #textbutton _("Q.Save") action QuickSave()
            #textbutton _("Q.Load") action QuickLoad()
            textbutton _("Prefs") action ShowMenu('preferences')


## This code ensures that the quick_menu screen is displayed in-game, whenever
## the player has not explicitly hidden the interface.
init python:
    config.overlay_screens.append("quick_menu")

default quick_menu = True

style quick_button is default
style quick_button_text is button_text

style quick_button:
    properties gui.button_properties("quick_button")

style quick_button_text:
    properties gui.button_text_properties("quick_button")


################################################################################
## Main and Game Menu Screens
################################################################################

## Navigation screen ###########################################################
##
## This screen is included in the main and game menus, and provides navigation
## to other menus, and to start the game.

screen navigation():

    # if not main_menu:
    #     vbox:
    #         style_prefix "navigation"
    #         xpos gui.navigation_xpos
    #         yalign 0.2
    #         textbutton _("Return to Game"):
    #             style "return_button"
    #             action Return()


    vbox:
        style_prefix "navigation"
        #xpos gui.navigation_xpos
        #yalign 0.5
        xpos gui.navigation_xpos
        yalign 0.71

        spacing #gui.navigation_spacing

        if main_menu:

            textbutton _("New Game") action Start(), Play("sound", "audio/gui/Select_noise.ogg") #hovered Play("sound", "audio/gui/menu_scroll.ogg")

            textbutton _("Load Game") action ShowMenu("load"), Play("sound", "audio/gui/Select_noise.ogg") #hovered Play("sound", "audio/gui/menu_scroll.ogg")

            textbutton _("About") action ShowMenu("about"), Play("sound", "audio/gui/Select_noise.ogg") #hovered Play("sound", "audio/gui/menu_scroll.ogg")

            textbutton _("Help") action ShowMenu("help"), Play("sound", "audio/gui/Select_noise.ogg") #hovered Play("sound", "audio/gui/menu_scroll.ogg")

        else:

            textbutton _("Return to Game") action Return(), Play("sound", "audio/gui/Select_noise.ogg") #hovered Play("sound", "audio/gui/menu_scroll.ogg") #yoffset -100

            textbutton _("Save Game") action ShowMenu("save"), Play("sound", "audio/gui/Select_noise.ogg") #hovered Play("sound", "audio/gui/menu_scroll.ogg")

            textbutton _("Load Game") action ShowMenu("load"), Play("sound", "audio/gui/Select_noise.ogg") #hovered Play("sound", "audio/gui/menu_scroll.ogg")

            textbutton _("Help") action ShowMenu("help"), Play("sound", "audio/gui/Select_noise.ogg") #hovered Play("sound", "audio/gui/menu_scroll.ogg")


        textbutton _("Options") action ShowMenu("preferences"), Play("sound", "audio/gui/Select_noise.ogg") #hovered Play("sound", "audio/gui/menu_scroll.ogg")

        if _in_replay:

            textbutton _("End Replay") action EndReplay(confirm=True), Play("sound", "audio/gui/Select_noise.ogg") #hovered Play("sound", "audio/gui/menu_scroll.ogg")

        elif not main_menu:

            textbutton _("Main Menu") action MainMenu(), Play("sound", "audio/gui/Select_noise.ogg") #hovered Play("sound", "audio/gui/menu_scroll.ogg")

        if renpy.variant("pc"):

            ## The quit button is banned on iOS and unnecessary on Android and
            ## Web.
            textbutton _("Quit") action Quit(confirm=not main_menu), Play("sound", "audio/gui/Select_noise.ogg") #hovered Play("sound", "audio/gui/menu_scroll.ogg")

        #textbutton _("About") action ShowMenu("about")


style navigation_button is gui_button
style navigation_button_text is gui_button_text

style navigation_button:
    size_group "navigation"
    properties gui.button_properties("navigation_button")

style navigation_button_text:
    properties gui.button_text_properties("navigation_button")


## Main Menu screen ############################################################
##
## Used to display the main menu when Ren'Py starts.
##
## https://www.renpy.org/doc/html/screen_special.html#main-menu

screen main_menu():

    ## This ensures that any other menu screen is replaced.
    tag menu

    style_prefix "main_menu"

    add gui.main_menu_background

    ## This empty frame darkens the main menu.
    frame:
        pass

    ## The use statement includes another screen inside this one. The actual
    ## contents of the main menu are in the navigation screen.
    use navigation

    # if gui.show_name:
    #
    #     vbox:
    #         text "[config.name!t]":
    #             style "main_menu_title"
    #
    #         text "[config.version]":
    #             style "main_menu_version"


style main_menu_frame is empty
style main_menu_vbox is vbox
style main_menu_text is gui_text
style main_menu_title is main_menu_text
style main_menu_version is main_menu_text

style main_menu_frame:
    xsize 420
    yfill True

    background "gui/overlay/main_menu.png"

style main_menu_vbox:
    xalign 1.0
    xoffset 0
    #xmaximum 1200
    yalign 0.0
    yoffset 0

style main_menu_text:
    properties gui.text_properties("main_menu", accent=True)

style main_menu_title:
    properties gui.text_properties("title")

style main_menu_version:
    properties gui.text_properties("version")


## Game Menu screen ############################################################
##
## This lays out the basic common structure of a game menu screen. It's called
## with the screen title, and displays the background, title, and navigation.
##
## The scroll parameter can be None, or one of "viewport" or "vpgrid". When
## this screen is intended to be used with one or more children, which are
## transcluded (placed) inside it.

screen game_menu(title, scroll=None, yinitial=0.0):

    style_prefix "game_menu"

    if main_menu:
        add gui.main_menu_background
    else:
        add gui.game_menu_background

    frame:
        style "game_menu_outer_frame"

        hbox:

            ## Reserve space for the navigation section.
            frame:
                style "game_menu_navigation_frame"

            frame:
                style "game_menu_content_frame"

                if scroll == "viewport":

                    viewport:
                        yinitial yinitial
                        scrollbars "vertical"
                        mousewheel True
                        draggable True
                        pagekeys True

                        side_yfill True

                        vbox:
                            transclude

                elif scroll == "vpgrid":

                    vpgrid:
                        cols 1
                        yinitial yinitial

                        scrollbars "vertical"
                        mousewheel True
                        draggable True
                        pagekeys True

                        side_yfill True

                        transclude

                else:

                    transclude

    use navigation

    # frame:
    #     style "game_menu_content_frame"
    #     #xpos 50#gui.navigation_xpos
    #     ypos 200
    #     textbutton _("Return"):
    #         style "return_button"
    #         action Return()

    label title

    if main_menu:
        key "game_menu" action ShowMenu("main_menu")


style game_menu_outer_frame is empty
style game_menu_navigation_frame is empty
style game_menu_content_frame is empty
style game_menu_viewport is gui_viewport
style game_menu_side is gui_side
style game_menu_scrollbar is gui_vscrollbar

style game_menu_label is gui_label
style game_menu_label_text is gui_label_text

style return_button is navigation_button
style return_button_text is navigation_button_text

style game_menu_outer_frame:
    bottom_padding 45
    top_padding 180

    background "gui/overlay/game_menu.png"

style game_menu_navigation_frame:
    xsize 420
    yfill True

style game_menu_content_frame:
    left_margin 60
    right_margin 30
    top_margin 15

style game_menu_viewport:
    xsize 1380

style game_menu_vscrollbar:
    unscrollable gui.unscrollable

style game_menu_side:
    spacing 15

style game_menu_label:
    xpos 75
    ysize 180

style game_menu_label_text:
    size gui.title_text_size
    color gui.accent_color
    yalign 0.5

style return_button:
    xpos gui.navigation_xpos
    yalign 1.0
    yoffset -45


## About screen ################################################################
##
## This screen gives credit and copyright information about the game and Ren'Py.
##
## There's nothing special about this screen, and hence it also serves as an
## example of how to make a custom screen.

screen about():

    tag menu

    ## This use statement includes the game_menu screen inside this one. The
    ## vbox child is then included inside the viewport inside the game_menu
    ## screen.
    use game_menu(_(""), scroll="viewport"):

        style_prefix "about"

        vbox:

            label "[config.name!t]"
            text _("Version [config.version!t]\n")

            ## gui.about is usually set in options.rpy.
            if gui.about:
                text "[gui.about!t]\n"

            text _("Made with {a=https://www.renpy.org/}Ren'Py{/a} [renpy.version_only].\n\n[renpy.license!t]")


## This is redefined in options.rpy to add text to the about screen.
define gui.about = ""


style about_label is gui_label
style about_label_text is gui_label_text
style about_text is gui_text

style about_label_text:
    size gui.label_text_size


## Load and Save screens #######################################################
##
## These screens are responsible for letting the player save the game and load
## it again. Since they share nearly everything in common, both are implemented
## in terms of a third screen, file_slots.
##
## https://www.renpy.org/doc/html/screen_special.html#save https://
## www.renpy.org/doc/html/screen_special.html#load

screen save():

    tag menu

    use file_slots(_("Save"))


screen load():

    tag menu

    use file_slots(_("Load"))


screen file_slots(title):

    default page_name_value = FilePageNameInputValue(pattern=_("Page {}"), auto=_("Automatic saves"), quick=_("Quick saves"))

    use game_menu(title):

        fixed:

            ## This ensures the input will get the enter event before any of the
            ## buttons do.
            order_reverse True

            ## The page name, which can be edited by clicking on a button.
            # button:
            #     style "page_label"
            #
            #     key_events True
            #     xalign 0.5
            #     action page_name_value.Toggle()
            #
            #     input:
            #         style "page_label_text"
            #         value page_name_value

            ## The grid of file slots.
            grid gui.file_slot_cols gui.file_slot_rows:
                style_prefix "slot"

                xalign 0.5
                yalign 0.5

                spacing gui.slot_spacing

                for i in range(gui.file_slot_cols * gui.file_slot_rows):

                    $ slot = i + 1

                    button:
                        action FileAction(slot)#, Play("sound", "audio/gui/Save_Game.ogg")

                        has vbox

                        add FileScreenshot(slot) xalign 0.5

                        text FileTime(slot, format=_("{#file_time}%A, %B %d %Y, %H:%M"), empty=_("empty slot")):
                            style "slot_time_text"

                        text FileSaveName(slot):
                            style "slot_name_text"

                        key "save_delete" action FileDelete(slot)

            ## Buttons to access other pages.
            hbox:
                style_prefix "page"

                xalign 0.1
                yalign 1.0

                spacing gui.page_spacing

                textbutton _("<") action FilePagePrevious()

                if config.has_autosave:
                    textbutton _("{#auto_page}A") action FilePage("auto")

                if config.has_quicksave:
                    textbutton _("{#quick_page}Q") action FilePage("quick")

                ## range(1, 10) gives the numbers from 1 to 9.
                for page in range(1, 10):
                    textbutton "[page]" action FilePage(page)

                textbutton _(">") action FilePageNext()


style page_label is gui_label
style page_label_text is gui_label_text
style page_button is gui_button
style page_button_text is gui_button_text

style slot_button is gui_button
style slot_button_text is gui_button_text
style slot_time_text is slot_button_text
style slot_name_text is slot_button_text

style page_label:
    xpadding 75
    ypadding 5

style page_label_text:
    text_align 0.5
    layout "subtitle"
    hover_color gui.hover_color

style page_button:
    properties gui.button_properties("page_button")

style page_button_text:
    properties gui.button_text_properties("page_button")

style slot_button:
    properties gui.button_properties("slot_button")

style slot_button_text:
    properties gui.button_text_properties("slot_button")


## Preferences screen ##########################################################
##
## The preferences screen allows the player to configure the game to better suit
## themselves.
##
## https://www.renpy.org/doc/html/screen_special.html#preferences

screen preferences():

    tag menu

    use game_menu(_(""), scroll="viewport"):

        vbox:

            xoffset 50
            #xmaximum 1000
            #spacing 10

            hbox:
                #box_wrap True
                #spacing  10
                #xsize 50
                #xfill True
                #size_group 50
                #cols 3

                if renpy.variant("pc") or renpy.variant("web"):

                    vbox:
                        style_prefix "radio"
                        label _("Display")
                        textbutton _("Window") action Preference("display", "window")
                        textbutton _("Fullscreen") action Preference("display", "fullscreen")

                vbox:
                    style_prefix "radio"
                    label _("Rollback Side")
                    textbutton _("Disable") action Preference("rollback side", "disable")
                    textbutton _("Left") action Preference("rollback side", "left")
                    textbutton _("Right") action Preference("rollback side", "right")

                vbox:
                    style_prefix "check"
                    label _("Skip")
                    textbutton _("Unseen Text") action Preference("skip", "toggle")
                    #textbutton _("After Choices") action Preference("after choices", "toggle")
                    #textbutton _("Transitions") action InvertSelected(Preference("transitions", "toggle"))

                ## Additional vboxes of type "radio_pref" or "check_pref" can be
                ## added here, to add additional creator-defined preferences.

            null height (4* gui.pref_spacing)

            hbox:
                style_prefix "slider"
                box_wrap True

                vbox:

                    label _("Text Speed")

                    bar value Preference("text speed")

                    #label _("Auto-Forward Time")

                    #bar value Preference("auto-forward time")

                vbox:

                    if config.has_music:
                        label _("Music Volume")

                        hbox:
                            bar value Preference("music volume")

                    if config.has_sound:

                        label _("Sound Volume")

                        hbox:
                            bar value Preference("sound volume")

                            if config.sample_sound:
                                textbutton _("Test") action Play("sound", config.sample_sound)


                    # if config.has_voice:
                    #     label _("Voice Volume")
                    #
                    #     hbox:
                    #         bar value Preference("voice volume")
                    #
                    #         if config.sample_voice:
                    #             textbutton _("Test") action Play("voice", config.sample_voice)

                    if config.has_music or config.has_sound or config.has_voice:
                        null height gui.pref_spacing

                        textbutton _("Mute All"):
                            action Preference("all mute", "toggle")
                            style "mute_all_button"


style pref_label is gui_label
style pref_label_text is gui_label_text
style pref_vbox is vbox

style radio_label is pref_label
style radio_label_text is pref_label_text
style radio_button is gui_button
style radio_button_text is gui_button_text
style radio_vbox is pref_vbox

style check_label is pref_label
style check_label_text is pref_label_text
style check_button is gui_button
style check_button_text is gui_button_text
style check_vbox is pref_vbox

style slider_label is pref_label
style slider_label_text is pref_label_text
style slider_slider is gui_slider
style slider_button is gui_button
style slider_button_text is gui_button_text
style slider_pref_vbox is pref_vbox

style mute_all_button is check_button
style mute_all_button_text is check_button_text

style pref_label:
    top_margin 100#gui.pref_spacing
    bottom_margin 3

style pref_label_text:
    yalign 1.0

style pref_vbox:
    xsize 338

style radio_vbox:
    spacing gui.pref_button_spacing

style radio_button:
    properties gui.button_properties("radio_button")
    foreground "gui/button/radio_[prefix_]foreground.png"

style radio_button_text:
    properties gui.button_text_properties("radio_button")

style check_vbox:
    spacing gui.pref_button_spacing

style check_button:
    properties gui.button_properties("check_button")
    foreground "gui/button/check_[prefix_]foreground.png"

style check_button_text:
    properties gui.button_text_properties("check_button")

style slider_slider:
    xsize 525

style slider_button:
    properties gui.button_properties("slider_button")
    yalign 0.5
    left_margin 15

style slider_button_text:
    properties gui.button_text_properties("slider_button")

style slider_vbox:
    xsize 675


## History screen ##############################################################
##
## This is a screen that displays the dialogue history to the player. While
## there isn't anything special about this screen, it does have to access the
## dialogue history stored in _history_list.
##
## https://www.renpy.org/doc/html/history.html

screen history():

    tag menu

    ## Avoid predicting this screen, as it can be very large.
    predict False

    use game_menu(_(""), scroll=("vpgrid" if gui.history_height else "viewport"), yinitial=1.0):

        style_prefix "history"

        for h in _history_list:

            window:

                ## This lays things out properly if history_height is None.
                has fixed:
                    yfit True

                if h.who:

                    label h.who:
                        style "history_name"
                        substitute False

                        ## Take the color of the who text from the Character, if
                        ## set.
                        if "color" in h.who_args:
                            text_color h.who_args["color"]

                $ what = renpy.filter_text_tags(h.what, allow=gui.history_allow_tags)
                text what:
                    substitute False

        if not _history_list:
            label _("The dialogue history is empty.")


## This determines what tags are allowed to be displayed on the history screen.

define gui.history_allow_tags = set()


style history_window is empty

style history_name is gui_label
style history_name_text is gui_label_text
style history_text is gui_text

style history_text is gui_text

style history_label is gui_label
style history_label_text is gui_label_text

style history_window:
    xfill True
    ysize gui.history_height

style history_name:
    xpos gui.history_name_xpos
    xanchor gui.history_name_xalign
    ypos gui.history_name_ypos
    xsize gui.history_name_width

style history_name_text:
    min_width gui.history_name_width
    text_align gui.history_name_xalign

style history_text:
    xpos gui.history_text_xpos
    ypos gui.history_text_ypos
    xanchor gui.history_text_xalign
    xsize gui.history_text_width
    min_width gui.history_text_width
    text_align gui.history_text_xalign
    layout ("subtitle" if gui.history_text_xalign else "tex")

style history_label:
    xfill True

style history_label_text:
    xalign 0.5


## Help screen #################################################################
##
## A screen that gives information about key and mouse bindings. It uses other
## screens (keyboard_help, mouse_help, and gamepad_help) to display the actual
## help.

screen help():

    tag menu

    default device = "keyboard"

    use game_menu(_(""), scroll="viewport"):

        style_prefix "help"

        vbox:
            spacing 23

            hbox:

                textbutton _("Keyboard + Mouse") action SetScreenVariable("device", "keyboard")
                #textbutton _("Mouse") action SetScreenVariable("device", "mouse")

                #if GamepadExists():
                #    textbutton _("Gamepad") action SetScreenVariable("device", "gamepad")

            # if device == "keyboard":
            #     use keyboard_help
            # elif device == "mouse":
            #     use mouse_help
            # elif device == "gamepad":
            #     use gamepad_help
            use keyboard_help


screen keyboard_help():

    hbox:
        label _("M1")
        text _("Advances dialogue or interacts with objects + choices.")

    hbox:
        label _("Enter")
        text _("Advances dialogue and activates the interface.")

    hbox:
        label _("Space")
        text _("Advances dialogue without selecting choices.")

    hbox:
        label _("Arrow Keys")
        text _("Navigate the interface.")

    hbox:
        label _("I")
        text _("Access the inventory screen.")

    hbox:
        label _("Escape")
        text _("Accesses the game menu.")

    # hbox:
    #     label _("Ctrl")
    #     text _("Skips dialogue while held down.")

    # hbox:
    #     label _("Tab")
    #     text _("Toggles dialogue skipping.")

    hbox:
        label _("Page Up")
        text _("Rolls back to earlier dialogue.")

    hbox:
        label _("Page Down")
        text _("Rolls forward to later dialogue.")

    hbox:
        label "H"
        text _("Hides the user interface.")

    hbox:
        label "S"
        text _("Takes a screenshot.")

    hbox:
        label "V"
        text _("Toggles assistive {a=https://www.renpy.org/l/voicing}self-voicing{/a}.")


screen mouse_help():

    hbox:
        label _("Left Click")
        text _("Advances dialogue and activates the interface.")

    hbox:
        label _("Middle Click")
        text _("Hides the user interface.")

    hbox:
        label _("Right Click")
        text _("Accesses the game menu.")

    hbox:
        label _("Mouse Wheel Up\nClick Rollback Side")
        text _("Rolls back to earlier dialogue.")

    hbox:
        label _("Mouse Wheel Down")
        text _("Rolls forward to later dialogue.")


screen gamepad_help():

    hbox:
        label _("Right Trigger\nA/Bottom Button")
        text _("Advances dialogue and activates the interface.")

    hbox:
        label _("Left Trigger\nLeft Shoulder")
        text _("Rolls back to earlier dialogue.")

    hbox:
        label _("Right Shoulder")
        text _("Rolls forward to later dialogue.")


    hbox:
        label _("D-Pad, Sticks")
        text _("Navigate the interface.")

    hbox:
        label _("Start, Guide")
        text _("Accesses the game menu.")

    hbox:
        label _("Y/Top Button")
        text _("Hides the user interface.")

    textbutton _("Calibrate") action GamepadCalibrate()


style help_button is gui_button
style help_button_text is gui_button_text
style help_label is gui_label
style help_label_text is gui_label_text
style help_text is gui_text

style help_button:
    properties gui.button_properties("help_button")
    xmargin 12

style help_button_text:
    properties gui.button_text_properties("help_button")

style help_label:
    xsize 375
    right_padding 30

style help_label_text:
    size gui.text_size
    xalign 1.0
    text_align 1.0



################################################################################
## Additional screens
################################################################################


## Confirm screen ##############################################################
##
## The confirm screen is called when Ren'Py wants to ask the player a yes or no
## question.
##
## https://www.renpy.org/doc/html/screen_special.html#confirm

screen confirm(message, yes_action, no_action):

    ## Ensure other screens do not get input while this screen is displayed.
    modal True

    zorder 200

    style_prefix "confirm"

    add "gui/overlay/confirm.png"

    frame:

        vbox:
            xalign .5
            yalign .5
            spacing 45

            label _(message):
                style "confirm_prompt"
                xalign 0.5

            hbox:
                xalign 0.5
                spacing 150

                textbutton _("Yes") action yes_action, Play("sound", "audio/gui/Save_Game.ogg") ##hovered Play("sound", "audio/gui/menu_scroll.ogg")
                textbutton _("No") action no_action, Play("sound", "audio/gui/menu_scroll.ogg")

    ## Right-click and escape answer "no".
    key "game_menu" action no_action


style confirm_frame is gui_frame
style confirm_prompt is gui_prompt
style confirm_prompt_text is gui_prompt_text
style confirm_button is gui_medium_button
style confirm_button_text is gui_medium_button_text

style confirm_frame:
    background Frame([ "gui/confirm_frame.png", "gui/frame.png"], gui.confirm_frame_borders, tile=gui.frame_tile)
    padding gui.confirm_frame_borders.padding
    xalign .5
    yalign .5

style confirm_prompt_text:
    text_align 0.5
    layout "subtitle"

style confirm_button:
    properties gui.button_properties("confirm_button")

style confirm_button_text:
    properties gui.button_text_properties("confirm_button")


## Skip indicator screen #######################################################
##
## The skip_indicator screen is displayed to indicate that skipping is in
## progress.
##
## https://www.renpy.org/doc/html/screen_special.html#skip-indicator

screen skip_indicator():

    zorder 100
    style_prefix "skip"

    frame:

        hbox:
            spacing 9

            text _("Skipping")

            text "▸" at delayed_blink(0.0, 1.0) style "skip_triangle"
            text "▸" at delayed_blink(0.2, 1.0) style "skip_triangle"
            text "▸" at delayed_blink(0.4, 1.0) style "skip_triangle"


## This transform is used to blink the arrows one after another.
transform delayed_blink(delay, cycle):
    alpha .5

    pause delay

    block:
        linear .2 alpha 1.0
        pause .2
        linear .2 alpha 0.5
        pause (cycle - .4)
        repeat


style skip_frame is empty
style skip_text is gui_text
style skip_triangle is skip_text

style skip_frame:
    ypos gui.skip_ypos
    background Frame("gui/skip.png", gui.skip_frame_borders, tile=gui.frame_tile)
    padding gui.skip_frame_borders.padding

style skip_text:
    size gui.notify_text_size

style skip_triangle:
    ## We have to use a font that has the BLACK RIGHT-POINTING SMALL TRIANGLE
    ## glyph in it.
    font "DejaVuSans.ttf"


## Notify screen ###############################################################
##
## The notify screen is used to show the player a message. (For example, when
## the game is quicksaved or a screenshot has been taken.)
##
## https://www.renpy.org/doc/html/screen_special.html#notify-screen

screen notify(message):

    zorder 100
    style_prefix "notify"

    frame at notify_appear:
        text "[message!tq]"

    timer 3.25 action Hide('notify')


transform notify_appear:
    on show:
        alpha 0
        linear .25 alpha 1.0
    on hide:
        linear .5 alpha 0.0


style notify_frame is empty
style notify_text is gui_text

style notify_frame:
    ypos gui.notify_ypos

    background Frame("gui/notify.png", gui.notify_frame_borders, tile=gui.frame_tile)
    padding gui.notify_frame_borders.padding

style notify_text:
    properties gui.text_properties("notify")


## NVL screen ##################################################################
##
## This screen is used for NVL-mode dialogue and menus.
##
## https://www.renpy.org/doc/html/screen_special.html#nvl


screen nvl(dialogue, items=None):

    window:
        style "nvl_window"

        has vbox:
            spacing gui.nvl_spacing

        ## Displays dialogue in either a vpgrid or the vbox.
        if gui.nvl_height:

            vpgrid:
                cols 1
                yinitial 1.0

                use nvl_dialogue(dialogue)

        else:

            use nvl_dialogue(dialogue)

        ## Displays the menu, if given. The menu may be displayed incorrectly if
        ## config.narrator_menu is set to True, as it is above.
        for i in items:

            textbutton i.caption:
                action i.action
                style "nvl_button"

    add SideImage() xalign 0.0 yalign 1.0


screen nvl_dialogue(dialogue):

    for d in dialogue:

        window:
            id d.window_id

            fixed:
                yfit gui.nvl_height is None

                if d.who is not None:

                    text d.who:
                        id d.who_id

                text d.what:
                    id d.what_id


## This controls the maximum number of NVL-mode entries that can be displayed at
## once.
define config.nvl_list_length = gui.nvl_list_length

style nvl_window is default
style nvl_entry is default

style nvl_label is say_label
style nvl_dialogue is say_dialogue

style nvl_button is button
style nvl_button_text is button_text

style nvl_window:
    xfill True
    yfill True

    background "gui/nvl.png"
    padding gui.nvl_borders.padding

style nvl_entry:
    xfill True
    ysize gui.nvl_height

style nvl_label:
    xpos gui.nvl_name_xpos
    xanchor gui.nvl_name_xalign
    ypos gui.nvl_name_ypos
    yanchor 0.0
    xsize gui.nvl_name_width
    min_width gui.nvl_name_width
    text_align gui.nvl_name_xalign

style nvl_dialogue:
    xpos gui.nvl_text_xpos
    xanchor gui.nvl_text_xalign
    ypos gui.nvl_text_ypos
    xsize gui.nvl_text_width
    min_width gui.nvl_text_width
    text_align gui.nvl_text_xalign
    layout ("subtitle" if gui.nvl_text_xalign else "tex")

style nvl_thought:
    xpos gui.nvl_thought_xpos
    xanchor gui.nvl_thought_xalign
    ypos gui.nvl_thought_ypos
    xsize gui.nvl_thought_width
    min_width gui.nvl_thought_width
    text_align gui.nvl_thought_xalign
    layout ("subtitle" if gui.nvl_text_xalign else "tex")

style nvl_button:
    properties gui.button_properties("nvl_button")
    xpos gui.nvl_button_xpos
    xanchor gui.nvl_button_xalign

style nvl_button_text:
    properties gui.button_text_properties("nvl_button")




################# CUSTOM SCREENS

###### basic stuff
# movement
screen checkMouse():
    zorder 100
    if standWalk==0:
        key "mousedown_1" action Jump("checkDist")

    ## add object list (somehow)
    if inventory_add_toggle:
        key "mousedown_1" action ToggleVariable("inventory_add_toggle"), Hide("inventory_add")
    # if not objectives_toggle:
    #     key "o" action ToggleVariable("objectives_toggle"), Show("objectives_screen")
    # else:
    #     key "o" action ToggleVariable("objectives_toggle"), Hide("objectives_screen")
    if not inventory_toggle:
        key "i" action ToggleVariable("inventory_toggle"), Show("inventory_screen")
    else:
        key "i" action ToggleVariable("inventory_toggle"), Hide("inventory_screen")

## overlays - consider making these drop downs instead of screen covers
# screen objectives_screen():
#     zorder 50
#     tag overlays
#     imagemap:
#         ground "overlays/overlay_objectives.png"

screen interaction_bg():
    zorder 49
    tag interactions_bg
    if infobox != "" and not cutscene:
        imagemap:
            ground "overlays/interact.png"
        text infobox xpos 40 ypos 20 color "#FFE394" size 100  #"#A1B4B2" size 100

screen inventory_screen():
    zorder 50
    tag overlays
    imagemap:
        ground "overlays/overlay_inventory.png"
    hbox:
        xpos 143
        ypos 223
        xsize 700
        ysize 298
        spacing 100
        # to-do: figure out how to enable item interaction when at certain locations
        if len(inventorylist) <= 5:
            vbox:
                for i in inventorylist:
                    textbutton i text_color "#5D261E" #action Return(i) #text_hover_color "#E9FF84" action Return(i)
        elif len(inventorylist) <= 10:
            vbox:
                for i in inventorylist[:5]:
                    textbutton i text_color "#5D261E" #action Return(i) #text_hover_color "#E9FF84" action Return(i)
            vbox:
                for i in inventorylist[5:]:
                    textbutton i text_color "#5D261E" #action Return(i) #text_hover_color "#E9FF84" action Return(i)
        else:
            vbox:
                for i in inventorylist[:5]:
                    textbutton i text_color "#5D261E"# action Return(i) #text_hover_color "#E9FF84" action Return(i)
            vbox:
                for i in inventorylist[5:10]:
                    textbutton i text_color "#5D261E" #action Return(i) #text_hover_color "#E9FF84" action Return(i)
            vbox:
                for i in inventorylist[10:15]:
                    textbutton i text_color "#5D261E" #action Return(i) #text_hover_color "#E9FF84" action Return(i)

screen inventory_add():
    zorder 51
    tag overlays
    imagemap:
        ground "overlays/inventoryadd.png"
    vbox:
        xalign 0.5
        yalign 0.45
        spacing 10
        # to-do: figure out how to enable item interaction when at certain locations
        hbox:
            xalign 0.5
            text "Added to inventory:" color "#FFFFFF"
        hbox:
            xalign 0.5
            text new_item color "#FAF67F" size 80

screen end_bad():
    zorder 99
    tag overlays
    imagemap:
        ground "bg/end_bad.png"
screen end_demo():
    zorder 99
    tag overlays
    imagemap:
        ground "bg/end_demo.png"


##### FLOOR 1
screen bedroom_screen_bg():
    tag maps
    zorder 0
    imagemap:
        ground "bg/bg_bedroom2.png"
        ##### add hotspots
        # dresser
        if not cutscene:
            hotspot (555, 463, 494, 314) action NullAction() hovered SetVariable("infobox","dresser") unhovered SetVariable("infobox", "")
            if mX > 455 and mX < 1155:
                hotspot (555, 463, 494, 314) action SetDict(floor1_ints, "bedroom_dresser", True) hovered SetVariable("infobox","dresser") unhovered SetVariable("infobox", "")
            # mirror
            hotspot (1042, 307, 187, 415) action NullAction() hovered SetVariable("infobox","mirror") unhovered SetVariable("infobox", "")
            if mX > 942 and mX < 1300:
                hotspot (1042, 307, 187, 415) action SetDict(floor1_ints, "bedroom_mirror", True) hovered SetVariable("infobox","mirror") unhovered SetVariable("infobox", "")
            # bed
            hotspot (1291, 365, 603, 473) action NullAction() hovered SetVariable("infobox","bed") unhovered SetVariable("infobox", "")
            if mX > 1191:
                hotspot (1291, 365, 603, 473) action SetDict(floor1_ints, "bedroom_bed", True) hovered SetVariable("infobox","bed") unhovered SetVariable("infobox", "")
            # picture
            #hotspot (793, 38, 177, 170) action SetDict(floor1_ints, "bedroom_picture", True),NullAction() hovered SetScreenVariable("bedroom_infobox_picture","picture") unhovered SetScreenVariable("bedroom_infobox_picture", "")
            # sports poster
            hotspot (1121, 15, 209, 185) action NullAction() hovered SetVariable("infobox","poster") unhovered SetVariable("infobox", "")
            if mX > 1021 and mX < 1430:
                hotspot (1121, 15, 209, 185) action SetDict(floor1_ints, "bedroom_poster", True) hovered SetVariable("infobox","poster") unhovered SetVariable("infobox", "")
            # medal
            hotspot (615, 333, 227, 122) action NullAction() hovered SetVariable("infobox","medal") unhovered SetVariable("infobox", "")
            if mX > 515 and mX < 950:
                hotspot (615, 333, 227, 122) action SetDict(floor1_ints, "bedroom_medal", True) hovered SetVariable("infobox","medal") unhovered SetVariable("infobox", "")
            # doll
            hotspot (1160, 669, 66, 210) action NullAction() hovered SetVariable("infobox","doll") unhovered SetVariable("infobox","")
            if mX > 1060 and mX < 1320:
                hotspot (1160, 669, 66, 210) action SetDict(floor1_ints, "bedroom_doll", True) hovered SetVariable("infobox","doll") unhovered SetVariable("infobox","")
            # door - hallway
            if (mX > 50-charadj_x and mX < 600-charadj_x):
                hotspot (100, 71, 407, 730) action SetVariable("prev_room", "bedroom"),SetDict(floor1_nav, "hallway", True) hovered SetVariable("infobox","exit to hallway") unhovered SetVariable("infobox", "")#SetVariable("floor1", "hallway")
            else:
                hotspot (100, 71, 407, 730) action NullAction() hovered SetVariable("infobox","exit to hallway") unhovered SetVariable("infobox", "")

screen bedroom_screen_top():
    tag interactables
    zorder 20

    imagebutton:
        idle "buttons/Soccerball.png"
        xpos 700
        ypos 930
        if not cutscene:
            hovered SetVariable("infobox","soccer ball") unhovered SetVariable("infobox", "")
            action SetDict(floor1_ints,"bedroom_soccer",True)
    imagebutton:
        idle "buttons/Pileofstuff.png"
        xpos 1700
        ypos 900
        if not cutscene:
            hovered SetVariable("infobox","pile of clothes") unhovered SetVariable("infobox", "")
            action SetDict(floor1_ints,"bedroom_pile", True)

screen hallway_screen_bg():
    tag maps
    zorder 0

    imagemap:
        ground "bg/bg_hallway.png"
        # add hotspot
        if not cutscene:
            hotspot (1600, 0, 320, 1080) action NullAction() hovered SetVariable("infobox","go to bedroom") unhovered SetVariable("infobox", "")
            hotspot (260, 71, 397, 701) action NullAction() hovered SetVariable("infobox","go to bathroom") unhovered SetVariable("infobox", "")
            hotspot (0, 0, 205, 1080) action NullAction() hovered SetVariable("infobox","go to living room") unhovered SetVariable("infobox", "")
            if not cutscene and (mX > 1006-charadj_x):
                hotspot (1600, 0, 320, 1080) action SetDict(floor1_nav, "bedroom", True) hovered SetVariable("infobox","go to bedroom") unhovered SetVariable("infobox", "")
            if not cutscene and (mX > 163-charadj_x and mX < 750-charadj_x):
                hotspot (260, 71, 397, 701) action SetDict(floor1_nav, "bathroom", True) hovered SetVariable("infobox","go to bathroom") unhovered SetVariable("infobox", "")
            if not cutscene and (mX < 300-charadj_x):
                hotspot (0, 0, 205, 1080) action SetDict(floor1_nav, "livingroom", True) hovered SetVariable("infobox","go to living room") unhovered SetVariable("infobox", "")

screen hallway_screen_top():
    tag interactables
    zorder 20
    imagebutton:
        idle "overlays/bg_hallway_doors.png"
        xpos 0
        ypos 0

screen bathroom_screen_bg():
    tag maps
    zorder 0

    imagemap:
        ground "bg/bg_bathroom.png"
        ##### add hotspot
        # sink
        if not cutscene:
            hotspot (737, 461, 453, 194) action NullAction() hovered SetVariable("infobox","sink") unhovered SetVariable("infobox", "")
            if not cutscene and (mX > 687-charadj_x and mX < 1230-charadj_x):
                hotspot (737, 461, 453, 194) action SetDict(floor1_ints, "bathroom_sink", True) hovered SetVariable("infobox","sink") unhovered SetVariable("infobox", "")#ToggleVariable("bathroom_sink_toggle")

            # door
            hotspot (1308, 32, 371, 769) action NullAction() hovered SetVariable("infobox","exit to hallway") unhovered SetVariable("infobox", "")
            if not cutscene and (mX > 1258-charadj_x and mX < 1720-charadj_x):
                hotspot (1308, 32, 371, 769) action SetVariable("prev_room", "bathroom"),SetDict(floor1_nav, "hallway", True) hovered SetVariable("infobox","exit to hallway") unhovered SetVariable("infobox", "")

screen bathroom_screen_top():
    tag interactables
    zorder 20

screen livingroom_screen_bg():
    tag maps
    zorder 0

    imagemap:
        if floor1_buttons["livingroom_boards"]:
            ground "bg/bg_livingroom_freedom.png"
        else:
            ground "bg/bg_livingroom.png"
        # add hotspot
        if not cutscene:
            hotspot (1620, 0, 300, 1080) action NullAction() hovered SetVariable("infobox","go to the hallway") unhovered SetVariable("infobox", "")
            if not cutscene and (mX > 1570-charadj_x):
                hotspot (1620, 0, 300, 1080) action SetVariable("prev_room", "livingroom"),SetDict(floor1_nav, "hallway", True) hovered SetVariable("infobox","go to the hallway") unhovered SetVariable("infobox", "")
            hotspot (882, 930, 590, 150) action NullAction() hovered SetVariable("infobox","go to the kitchen") unhovered SetVariable("infobox", "")
            if mX > 782 and mX < 1550:
                hotspot (882, 930, 590, 150) action SetVariable("prev_room", "livingroom"),SetDict(floor1_nav, "kitchen", True) hovered SetVariable("infobox","go to the kitchen") unhovered SetVariable("infobox", "")
            hotspot (1302, 452, 410, 264) action NullAction() hovered SetVariable("infobox","TV") unhovered SetVariable("infobox", "")
            if mX > 1202:
                hotspot (1302, 452, 410, 264) action SetDict(floor1_ints,"livingroom_TV",True) hovered SetVariable("infobox","TV") unhovered SetVariable("infobox", "")
            hotspot (695, 170, 446, 423) action NullAction() hovered SetVariable("infobox","window") unhovered SetVariable("infobox", "")
            if floor1_buttons["livingroom_boards"] == True:
                if not cutscene and (mX > 648-charadj_x and mX < 1200-charadj_x):
                    hotspot (698, 174, 440, 413) action SetVariable("prev_room", "livingroom"),SetDict(floor1_nav, "stairs_f1", True) hovered SetVariable("infobox","window") unhovered SetVariable("infobox", "")
            else:
                if mX > 648-charadj_x and mX < 1200-charadj_x:
                    hotspot (698, 174, 440, 413) action SetDict(floor1_ints,"livingroom_boards",True) hovered SetVariable("infobox","window") unhovered SetVariable("infobox", "")

    # family portrait
    if floor1_buttons["livingroom_portrait"] == True:
        imagebutton:
            idle "buttons/family_portrait.png"
            xpos 75
            ypos 132
            if not cutscene:
                hovered SetVariable("infobox","family portrait") unhovered SetVariable("infobox", "")
                action SetDict(floor1_ints,"livingroom_portrait",True)#,Jump("checkDist")
    # boards
    if floor1_buttons["livingroom_boards"] == True:
        imagebutton:
            idle "buttons/Boards.png"
            xpos 350
            ypos 420
            # if not cutscene:
            #     #hover "buttons/meg.png"
            #     action SetDict(floor1_ints,"livingroom_boards",True)


screen livingroom_screen_top():
    tag interactables
    zorder 20

screen kitchen_screen_bg():
    tag maps
    zorder 0

    imagemap:
        ground "bg/bg_kitchen.png"
        # add hotspot
        if not cutscene:
            hotspot (1341, 21, 468, 789) action NullAction() hovered SetVariable("infobox","go to the living room") unhovered SetVariable("infobox", "")
            if not cutscene and (mX > 1291-charadj_x and mX < 1860-charadj_x):
                hotspot (1341, 21, 468, 789) action SetVariable("prev_room", "kitchen"),SetDict(floor1_nav, "livingroom", True) hovered SetVariable("infobox","go to the living room") unhovered SetVariable("infobox", "")
            hotspot (0, 102, 381, 679) action NullAction() hovered SetVariable("infobox","fridge") unhovered SetVariable("infobox", "")
            if not cutscene and (mX > 0-charadj_x and mX < 431-charadj_x):
                hotspot (0, 102, 381, 679) action SetDict(floor1_ints, "kitchen_fridge", True) hovered SetVariable("infobox","fridge") unhovered SetVariable("infobox", "")
            hotspot (624, 431, 423, 331) action NullAction() hovered SetVariable("infobox", "under sink") unhovered SetVariable("infobox", "")
            if not cutscene and (mX > 574-charadj_x and mX < 1100-charadj_x):
                hotspot (624, 431, 423, 331) action SetDict(floor1_ints, "kitchen_undersink", True) hovered SetVariable("infobox", "under sink") unhovered SetVariable("infobox", "")

    if floor1_buttons["kitchen_stepstool"] == True:
        imagebutton:
            idle "buttons/stepstool.png"
            xpos 350
            ypos 650
            if not cutscene:
                #hover "buttons/stepstool_h.png"
                hovered SetVariable("infobox", "stepstool") unhovered SetVariable("infobox", "")
                action SetDict(floor1_ints,"kitchen_stepstool",True)
    if floor1_buttons["kitchen_stepstool_placed"] == True:
        imagebutton:
            idle "buttons/stepstool.png"
            xpos 168
            ypos 671

screen kitchen_screen_top():
    tag interactables
    zorder 20

screen stairs_f1_screen_bg():
    tag maps
    zorder 0

    imagemap:
        ground "bg/bg_stairs.png"
        # add hotspot
        # living room
        if not cutscene:
            hotspot (0, 0, 100, 1080) action NullAction() hovered SetVariable("infobox","go to the living room") unhovered SetVariable("infobox", "")
            if not cutscene and (mX < 300-charadj_x):
                hotspot (0, 0, 100, 1080) action SetVariable("prev_room", "stairs_f1"),SetDict(floor1_nav, "livingroom", True) hovered SetVariable("infobox","go to the living room") unhovered SetVariable("infobox", "")
            # 2nd floor ladder (450, 0, 375, 500)
            hotspot (450, 0, 375, 500) action NullAction() hovered SetVariable("infobox","go to the second floor") unhovered SetVariable("infobox", "")
            if not cutscene and (mX < 300-charadj_x):
                hotspot (450, 0, 375, 500) action SetDict(floor1_ints,"stairs_f1_ladder", True) hovered SetVariable("infobox","go to the second floor") unhovered SetVariable("infobox", "")


screen stairs_f1_screen_top():
    tag interactables
    zorder 20
    imagebutton:
        background "overlays/mist1.png"
        idle "overlays/mist1.png"
        xpos 0
        ypos 0


##### FLOOR 2
screen stairs_f2_screen_bg():
    tag maps
    zorder 0

    imagemap:
        ground "bg/stairs2.png"
        # add hotspot
        if not cutscene:
            # ladder
            hotspot (484, 869, 689, 176) action NullAction() hovered SetVariable("infobox","ladder to first floor") unhovered SetVariable("infobox", "")
            if not cutscene and (mX > 384-charadj_x and mX < 1300-charadj_x):
                hotspot (484, 869, 689, 176) action  SetDict(floor2_ints,"stairs_f2_ladder", True) hovered SetVariable("infobox","stairs to first floor") unhovered SetVariable("infobox", "")
            # bedroom2
            hotspot (774, 129, 276, 492) action NullAction() hovered SetVariable("infobox","go in") unhovered SetVariable("infobox", "")
            if not cutscene and (mX > 674-charadj_x and mX < 1200-charadj_x):
                hotspot (774, 129, 276, 492) action SetVariable("prev_room", "stairs_f2"),SetDict(floor2_nav, "bedroom2", True) hovered SetVariable("infobox","go in") unhovered SetVariable("infobox", "")


screen stairs_f2_screen_top():
    tag interactables
    zorder 20
    imagebutton:
        background "overlays/mist2.png"
        idle "overlays/mist2.png"
        xpos 0
        ypos 0

screen bedroom2_screen_bg():
    tag maps
    zorder 0

    imagemap:
        if floor2_buttons["bedroom2_lantern_chain"] == True:
            ground "bg/bedroom2.png"
        else:
            ground "bg/bedroom2_fall.png"
        # add hotspot
        if not cutscene:
            # window
            # hotspot (1578, 192, 314, 445) action NullAction() hovered SetVariable("infobox","go outside") unhovered SetVariable("infobox", "")
            # if not cutscene and (mX > 1478-charadj_x and mX < 2000-charadj_x):
            #     hotspot (1578, 192, 314, 445) action SetVariable("prev_room", "bedroom2"),SetDict(floor2_nav, "stairs_f2", True) hovered SetVariable("infobox","go outside") unhovered SetVariable("infobox", "")
            # hallway
            hotspot (0, 131, 300, 650) action NullAction() hovered SetVariable("infobox","go further in") unhovered SetVariable("infobox", "")
            if not cutscene and (mX < 400-charadj_x):
                hotspot (0, 131, 300, 650) action SetVariable("prev_room", "bedroom2"),SetDict(floor2_nav, "hallway2", True) hovered SetVariable("infobox","go further in") unhovered SetVariable("infobox", "")
            # bed
            hotspot (1179, 529, 609, 264) action NullAction() hovered SetVariable("infobox","bed...?") unhovered SetVariable("infobox", "")
            if not cutscene and (mX > 1079-charadj_x and mX < 2000-charadj_x):
                hotspot (1179, 529, 609, 264) action SetDict(floor2_ints, "bedroom2_bed", True) hovered SetVariable("infobox","bed...?") unhovered SetVariable("infobox", "")
            if floor2_buttons["bedroom2_lantern_chain"] == True:
                # lantern
                hotspot (326, 199, 114, 157) action NullAction() hovered SetVariable("infobox","hanging lantern") unhovered SetVariable("infobox", "")
                if not cutscene and (mX > 226-charadj_x and mX < 440-charadj_x):
                    hotspot (326, 199, 114, 157) action SetDict(floor2_ints, "bedroom2_lantern_chain", True) hovered SetVariable("infobox","hanging lantern") unhovered SetVariable("infobox", "")
            else:
                # lantern fall
                hotspot (310, 891, 200, 127) action NullAction() hovered SetVariable("infobox","fallen lantern") unhovered SetVariable("infobox", "")
                if not cutscene and (mX > 210-charadj_x and mX < 610-charadj_x):
                    hotspot (310, 891, 200, 127) action SetDict(floor2_ints, "bedroom2_lantern", True) hovered SetVariable("infobox","fallen lantern") unhovered SetVariable("infobox", "")


screen bedroom2_screen_top():
    tag interactables
    zorder 20
    imagebutton:
        idle "overlays/bedroom2_doors.png"
        xpos 0
        ypos 0

screen livingroom2_screen_bg():
    tag maps
    zorder 0

    imagemap:
        if not trigger_goodend:
            ground "bg/livingroom2.png"
        else:
            ground "bg/livingroom2_open.png"
        # add hotspot
        if not cutscene:
            # hallway
            hotspot (0, 0, 300, 1080) action NullAction() hovered SetVariable("infobox","return to hallway") unhovered SetVariable("infobox", "")
            if (mX < 400-charadj_x):
                hotspot (0, 0, 300, 1080) action SetVariable("prev_room", "livingroom2"),SetDict(floor2_nav, "hallway2", True) hovered SetVariable("infobox","return to hallway") unhovered SetVariable("infobox", "")
            # couch
            hotspot (1206, 516, 659, 287) action NullAction() hovered SetVariable("infobox","couch") unhovered SetVariable("infobox", "")
            if (mX > 1106-charadj_x):
                hotspot (1206, 516, 659, 287) action SetDict(floor2_ints, "livingroom2_couch", True) hovered SetVariable("infobox","couch") unhovered SetVariable("infobox", "")
            # window
            hotspot (523, 108, 329, 541) action NullAction() hovered SetVariable("infobox","window") unhovered SetVariable("infobox", "")
            if (mX > 423-charadj_x and mX < 1000-charadj_x):
                hotspot (523, 108, 329, 541) action SetDict(floor2_ints, "livingroom2_window", True) hovered SetVariable("infobox","window") unhovered SetVariable("infobox", "")

screen livingroom2_screen_top():
    tag interactables
    zorder 20
    imagebutton:
        idle "overlays/livingroom2_doors.png"
        xpos 0
        ypos 0

screen hallway2_screen_bg():
    tag maps
    zorder 0

    imagemap:
        ground "bg/hallway2.png"
        # add hotspot
        if not cutscene:
            # chapel2
            hotspot (0, 58, 137, 723) action NullAction() hovered SetVariable("infobox","go to next room") unhovered SetVariable("infobox", "")
            if not cutscene and (mX < 300-charadj_x):
                hotspot (0, 58, 137, 723) action  SetVariable("prev_room", "hallway2"),SetDict(floor2_nav, "chapel2", True) hovered SetVariable("infobox","go to next room") unhovered SetVariable("infobox", "")
            # bedroom2
            hotspot (1438, 51, 415, 730) action NullAction() hovered SetVariable("infobox","go back to 'bedroom'") unhovered SetVariable("infobox", "")
            if not cutscene and (mX > 1338-charadj_x and mX < 1950-charadj_x):
                hotspot (1438, 51, 415, 730) action SetVariable("prev_room", "hallway2"),SetDict(floor2_nav, "bedroom2", True) hovered SetVariable("infobox","go back to 'bedroom'") unhovered SetVariable("infobox", "")
            # livingroom2
            hotspot (1162, 900, 431, 180) action NullAction() hovered SetVariable("infobox", "enter side room") unhovered SetVariable("infobox", "")
            if mX > 1062:
                hotspot (1162, 900, 431, 180) action SetVariable("prev_room", "hallway2"),SetDict(floor2_nav, "livingroom2", True) hovered SetVariable("infobox", "enter side room") unhovered SetVariable("infobox", "")
            # lantern
            hotspot (704, 236, 96, 158) action NullAction() hovered SetVariable("infobox","hanging lantern") unhovered SetVariable("infobox", "")
            if not cutscene and (mX > 604-charadj_x and mX < 900-charadj_x):
                hotspot (704, 236, 96, 158) action SetDict(floor2_ints, "hallway2_lantern", True) hovered SetVariable("infobox","hanging lantern") unhovered SetVariable("infobox", "")

    # imagebutton:
    #     background "buttons/alex2.png"
    #     idle "buttons/alex2.png"
    #     xpos 900
    #     ypos 0
    #     if not cutscene:
    #         hovered SetVariable("infobox","hanging lantern") unhovered SetVariable("infobox", "")
    #         action SetDict(floor2_ints,"hallway2_lantern",True)


screen hallway2_screen_top():
    tag interactables
    zorder 20
    imagebutton:
        idle "overlays/hallway2_doors.png"
        xpos 0
        ypos 0
    imagebutton:
        background "overlays/rockshall1.png"
        idle "overlays/rockshall1.png"
        xpos 0
        ypos 479
    imagebutton:
        background "overlays/rockshall2.png"
        idle "overlays/rockshall2.png"
        xpos 0
        ypos 0

screen chapel2_screen_bg():
    tag maps
    zorder 0

    imagemap:
        ground "bg/chapel2.png"
        # add hotspot
        if not cutscene:
            # statue
            hotspot (877, 48, 207, 399) action NullAction() hovered SetVariable("infobox","statue") unhovered SetVariable("infobox", "")
            if not cutscene and (mX > 777-charadj_x and mX < 1177):
                hotspot (877, 48, 207, 399) action  SetDict(floor2_ints,"chapel2_statue",True) hovered SetVariable("infobox","statue") unhovered SetVariable("infobox", "")
            # hallway
            hotspot (1800, 0, 220, 1080) action NullAction() hovered SetVariable("infobox","go back to hallway") unhovered SetVariable("infobox", "")
            if not cutscene and (mX > 1700-charadj_x):
                hotspot (1800, 0, 220, 1080) action  SetVariable("prev_room", "chapel2"),SetDict(floor2_nav, "hallway2", True) hovered SetVariable("infobox","go back to hallway") unhovered SetVariable("infobox", "")
            # chapel
            hotspot (0, 20, 300, 762) action NullAction() hovered SetVariable("infobox","go to next room") unhovered SetVariable("infobox", "")
            if not cutscene and (mX < 400-charadj_x):
               hotspot (0, 20, 300, 762) action SetVariable("prev_room", "chapel2"),SetDict(floor2_nav, "painting2", True) hovered SetVariable("infobox","go to next room") unhovered SetVariable("infobox", "")
            # grave1
            hotspot (391, 565, 283, 240) action NullAction() hovered SetVariable("infobox","first grave") unhovered SetVariable("infobox", "")
            if mX > 291-charadj_x and mX < 780-charadj_x:
                hotspot (391, 565, 283, 240) action SetDict(floor2_ints,"chapel2_grave1",True) hovered SetVariable("infobox","first grave") unhovered SetVariable("infobox", "")
            # grave2
            hotspot (695, 588, 276, 211) action NullAction() hovered SetVariable("infobox","second grave") unhovered SetVariable("infobox", "")
            if mX > 595-charadj_x and mX < 1070-charadj_x:
                hotspot (695, 588, 276, 211) action SetDict(floor2_ints,"chapel2_grave2",True) hovered SetVariable("infobox","second grave") unhovered SetVariable("infobox", "")
            # grave3
            hotspot (1039, 561, 287, 249) action NullAction() hovered SetVariable("infobox","third grave") unhovered SetVariable("infobox", "")
            if mX > 939-charadj_x and mX < 1410-charadj_x:
                hotspot (1039, 561, 287, 249) action SetDict(floor2_ints,"chapel2_grave3",True) hovered SetVariable("infobox","third grave") unhovered SetVariable("infobox", "")
            # grave4
            hotspot (1368, 463, 292, 378) action NullAction() hovered SetVariable("infobox","fourth grave") unhovered SetVariable("infobox", "")
            if mX > 1268-charadj_x and mX < 1768-charadj_x:
                hotspot (1368, 463, 292, 378) action SetDict(floor2_ints,"chapel2_grave4",True) hovered SetVariable("infobox","fourth grave") unhovered SetVariable("infobox", "")


    if floor2_buttons["chapel2_grave1"] == False:
        imagebutton:
            background "buttons/grave1.png"
            idle "buttons/grave1.png"
            xpos 0
            ypos 0

    if floor2_buttons["chapel2_grave2"] == False:
        imagebutton:
            background "buttons/grave2.png"
            idle "buttons/grave2.png"
            xpos 0
            ypos 0

    if floor2_buttons["chapel2_grave3"] == False:
        imagebutton:
            background "buttons/grave3.png"
            idle "buttons/grave3.png"
            xpos 0
            ypos 0

    if floor2_buttons["chapel2_grave4"] == False:
        imagebutton:
            background "buttons/grave4.png"
            idle "buttons/grave4.png"
            xpos 0
            ypos 0

screen chapel2_screen_top():
    tag interactables
    zorder 20

    if floor2_buttons["chapel2_shovel"] == True:
        imagebutton:
            background "buttons/shovel.png"
            idle "buttons/shovel.png"
            xpos 1700
            ypos 800
            if not cutscene:
                hovered SetVariable("infobox","cross") unhovered SetVariable("infobox", "")
                action SetDict(floor2_ints,"chapel2_shovel",True)
    imagebutton:
        idle "overlays/chapel2_doors.png"
        xpos 0
        ypos 0

screen painting2_screen_bg():
    tag maps
    zorder 0

    imagemap:
        ground "bg/painting2.png"
        # add hotspot
        if not cutscene:
            # chapel2
            hotspot (1600, 0, 320, 1080) action NullAction() hovered SetVariable("infobox","go back") unhovered SetVariable("infobox", "")
            if not cutscene and (mX > 1500-charadj_x):
                hotspot (1600, 0, 320, 1080) action  SetVariable("prev_room", "painting2"),SetDict(floor2_nav, "chapel2", True) hovered SetVariable("infobox","go back") unhovered SetVariable("infobox", "")
            # painting
            hotspot (794, 213, 190, 294) action NullAction() hovered SetVariable("infobox","large painting") unhovered SetVariable("infobox", "")
            if not cutscene and (mX > 694-charadj_x and mX < 1094-charadj_x):
                hotspot (794, 213, 190, 294) action SetDict(floor2_ints,"painting2_painting",True) hovered SetVariable("infobox","large painting") unhovered SetVariable("infobox", "")
            #hotspot (200, 500, 100, 100) action NullAction() hovered SetScreenVariable("painting2_infobox","large painting description") unhovered SetScreenVariable("painting2_infobox", "")
            #if not cutscene and (mX > 100-charadj_x and mX < 400-charadj_x):
            #    hotspot (200, 500, 100, 100) action SetDict(floor2_ints,"painting2_painting_label",True) hovered SetScreenVariable("painting2_infobox","large painting description") unhovered SetScreenVariable("painting2_infobox", "")
            #hotspot (500, 491, 1000, 182)
            hotspot (1013, 466, 44, 49)action NullAction() hovered SetVariable("infobox","first boy") unhovered SetVariable("infobox", "")
            if mX > 900 and mX < 1300:
                hotspot (1013, 466, 44, 49) action SetDict(floor2_ints,"painting2_boy1",True) hovered SetVariable("infobox","first boy") unhovered SetVariable("infobox", "")
            hotspot (1051, 390, 47, 46) action NullAction() hovered SetVariable("infobox","second boy") unhovered SetVariable("infobox", "")
            if mX > 900 and mX < 1300:
                hotspot (1051, 390, 47, 46) action SetDict(floor2_ints,"painting2_boy2",True) hovered SetVariable("infobox","second boy") unhovered SetVariable("infobox", "")
            hotspot (1073, 479, 58, 58) action NullAction() hovered SetVariable("infobox","third boy") unhovered SetVariable("infobox", "")
            if mX > 900 and mX < 1300:
                hotspot (1073, 479, 58, 58) action SetDict(floor2_ints,"painting2_boy3",True) hovered SetVariable("infobox","third boy") unhovered SetVariable("infobox", "")
            hotspot (1105, 409, 47, 45) action NullAction() hovered SetVariable("infobox","fourth boy") unhovered SetVariable("infobox", "")
            if mX > 900 and mX < 1300:
                hotspot (1105, 409, 47, 45) action SetDict(floor2_ints,"painting2_boy4",True) hovered SetVariable("infobox","fourth boy") unhovered SetVariable("infobox", "")



screen painting2_screen_top():
    tag interactables
    zorder 20

    imagebutton:
        idle "overlays/painting2_doors.png"
        xpos 0
        ypos 0

    if "Shiny Bracelet" in inventorylist:
        imagebutton:
            #background "overlays/paintingglow1.png"
            idle "overlays/paintingglow1.png"
            xpos 0
            ypos 0
            hover "overlays/paintingglow2.png"
    imagebutton:
        background "overlays/rocks.png"
        idle "overlays/rocks.png"
        xpos 0
        ypos 836


#################################################### TEST SCREENS
# buttons - room test
screen Int_Test():
    # screens with this tag will be swapped out when one is shown
    tag maps

    zorder 0

    imagemap:
        ground "bg/bg1.png"
        if not cutscene and (mX > 6 and mX < 700):
            hotspot (106, 97, 481, 870) action SetVariable("floor1", "room2")

screen Int_Test_Top():
    # screens with this tag will be swapped out when one is shown
    tag interactables

    zorder 20

    if floor1_buttons["a1"] == True:
        imagebutton:
            xalign 0.75
            yalign 0.75
            idle "buttons/alex.png"
            if not cutscene:
                hover "buttons/meg.png"
                action ToggleDict(floor1_buttons_prep,"a1"),ToggleVariable("button_alex"),Jump("checkDist")

    if floor1_buttons["a2"] == True:
        imagebutton:
            xalign 0.25
            yalign 0.95
            idle "buttons/alex.png"
            if not cutscene:
                hover "buttons/meg.png"
                action ToggleDict(floor1_buttons_prep,"a2"),ToggleVariable("button_alex"),Jump("checkDist")

screen Int_Test2():
    tag maps

    zorder 0

    imagemap:
        ground "bg/bg2.png"
        if not cutscene and (mX > 1240 and mX < 1900):
            hotspot (1340, 93, 466, 871) action SetVariable("floor1", "room1")

screen Int_Test2_Top():
    tag interactables

    zorder 20

    if floor1_buttons["a3"] == True:
        imagebutton:
            xalign 0.15
            yalign 0.40
            idle "buttons/alex.png"
            if not cutscene:
                hover "buttons/meg.png"
                action ToggleDict(floor1_buttons_prep,"a3"),ToggleVariable("button_alex"),Jump("checkDist")


################# FROM map_screen.rpy
# from elaine demo
# screen map_screen(aMap):
#     # where do we add the bg?
#
#     # add a black bg
#     add "#000"
#
#     # based on 100 tile size, remember!!
#     $ offset_x = 960 - (100 * aMap.center_x) + 50
#     $ offset_y = 540 - (100 * aMap.center_y) + 50
#
#     # placed bg!
#     add aMap.img:
#         pos(offset_x, offset_y)
#
#     # show character
#     for i in range(len(aMap.map)):
#         $ row = aMap.map[i]
#         for j in range(len(row)):
#             $ tile = row[j]
#             if not tile.occupant is None:
#                 $ off_x, off_y = tile.occupant.getOffset()
#                 # where to put left hand corner of bg image
#                 $ tile_lc_x = 100 * j  + offset_x
#                 $ tile_lc_y = 100 * i + offset_y
#                 add tile.occupant.img:
#                     pos(tile_lc_x + off_x, tile_lc_y + off_y)

################################################################################
## Mobile Variants
################################################################################

style pref_vbox:
    variant "medium"
    xsize 675

## Since a mouse may not be present, we replace the quick menu with a version
## that uses fewer and bigger buttons that are easier to touch.
screen quick_menu():
    variant "touch"

    zorder 100

    if quick_menu:

        hbox:
            style_prefix "quick"

            xalign 0.5
            yalign 1.0

            textbutton _("Back") action Rollback()
            textbutton _("Skip") action Skip() alternate Skip(fast=True, confirm=True)
            #textbutton _("Auto") action Preference("auto-forward", "toggle")
            textbutton _("Menu") action ShowMenu()


style window:
    variant "small"
    background "gui/phone/textbox.png"

style radio_button:
    variant "small"
    foreground "gui/phone/button/radio_[prefix_]foreground.png"

style check_button:
    variant "small"
    foreground "gui/phone/button/check_[prefix_]foreground.png"

style nvl_window:
    variant "small"
    background "gui/phone/nvl.png"

style main_menu_frame:
    variant "small"
    background "gui/phone/overlay/main_menu.png"

style game_menu_outer_frame:
    variant "small"
    background "gui/phone/overlay/game_menu.png"

style game_menu_navigation_frame:
    variant "small"
    xsize 510

style game_menu_content_frame:
    variant "small"
    top_margin 0

style pref_vbox:
    variant "small"
    xsize 600

style bar:
    variant "small"
    ysize gui.bar_size
    left_bar Frame("gui/phone/bar/left.png", gui.bar_borders, tile=gui.bar_tile)
    right_bar Frame("gui/phone/bar/right.png", gui.bar_borders, tile=gui.bar_tile)

style vbar:
    variant "small"
    xsize gui.bar_size
    top_bar Frame("gui/phone/bar/top.png", gui.vbar_borders, tile=gui.bar_tile)
    bottom_bar Frame("gui/phone/bar/bottom.png", gui.vbar_borders, tile=gui.bar_tile)

style scrollbar:
    variant "small"
    ysize gui.scrollbar_size
    base_bar Frame("gui/phone/scrollbar/horizontal_[prefix_]bar.png", gui.scrollbar_borders, tile=gui.scrollbar_tile)
    thumb Frame("gui/phone/scrollbar/horizontal_[prefix_]thumb.png", gui.scrollbar_borders, tile=gui.scrollbar_tile)

style vscrollbar:
    variant "small"
    xsize gui.scrollbar_size
    base_bar Frame("gui/phone/scrollbar/vertical_[prefix_]bar.png", gui.vscrollbar_borders, tile=gui.scrollbar_tile)
    thumb Frame("gui/phone/scrollbar/vertical_[prefix_]thumb.png", gui.vscrollbar_borders, tile=gui.scrollbar_tile)

style slider:
    variant "small"
    ysize gui.slider_size
    base_bar Frame("gui/phone/slider/horizontal_[prefix_]bar.png", gui.slider_borders, tile=gui.slider_tile)
    thumb "gui/phone/slider/horizontal_[prefix_]thumb.png"

style vslider:
    variant "small"
    xsize gui.slider_size
    base_bar Frame("gui/phone/slider/vertical_[prefix_]bar.png", gui.vslider_borders, tile=gui.slider_tile)
    thumb "gui/phone/slider/vertical_[prefix_]thumb.png"

style slider_pref_vbox:
    variant "small"
    xsize None

style slider_pref_slider:
    variant "small"
    xsize 900
